@@ -8,14 +8,15 @@ parentFolder = os.getcwd()
 print("Generate Quotes from Goodreads website.\n")
 author = input("Author to search:\n")
 book = input("Book name as per Goodreads:\n")
-saveFile = f"{author}.txt"
+pickleFile = f"{author}.pickle"
+saveFile = f"{author}_filtered_quotes.txt"
 
 # pickle = f"{parentFolder}\\{author}"
 # gr.Quotes.generateDB(author,saveFile=pickle)
 if os.path.isfile(saveFile):
-    db = gr.Quotes.loadDB(saveFile)
+    db = gr.Quotes.loadDB(pickleFile)
 else:
-    db = gr.Quotes.generateDB(author, saveFile=f"{author}.txt")
+    db = gr.Quotes.generateDB(author, saveFile=pickleFile)
 # titles = gr.Quotes.bookTitles(db)
 # print(titles)
 
