@@ -34,7 +34,7 @@ class File:
         If file did not exist it creates a file"""
 
         if self.encode != None:
-            # content = content.encode(self.encode)
+            content = content.encode(self.encode)
             f = open(self.fileName, "wb")
         else:
             f = open(self.fileName, "w")
@@ -47,9 +47,9 @@ class File:
         if self.encode != None:
             nextLine = nextLine.encode(self.encode)
             content = content.encode(self.encode)
-
-
-        f = open(self.fileName, "a")
+            f = open(self.fileName, "ab")
+        else:
+            f = open(self.fileName, "a")
         f.write(nextLine + content) if newline else f.write(content)
         f.close()
 
